Struct
QmiMessageWdsBindSubscriptionInput
since: 1.37
Description [src]
struct QmiMessageWdsBindSubscriptionInput {
/* No available fields */
}
The QmiMessageWdsBindSubscriptionInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Constructors
qmi_message_wds_bind_subscription_input_new
Allocates a new QmiMessageWdsBindSubscriptionInput.
since: 1.37
Instance methods
qmi_message_wds_bind_subscription_input_get_subscription_id
Get the ‘Subscription Id’ field from self.
since: 1.37
qmi_message_wds_bind_subscription_input_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_message_wds_bind_subscription_input_set_subscription_id
Set the ‘Subscription Id’ field in the message.
since: 1.37
qmi_message_wds_bind_subscription_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37